@@ -46,11 +46,21 @@
  */
 #define strsize(S) (sizeof(S) - 1)
 
+/*
+ * NGHTTP3_TEST_MAP_SEED is the seed passed to nghttp3_map_init.
+ */
+#define NGHTTP3_TEST_MAP_SEED 0
+
+typedef struct nghttp3_raw_frame_hd {
+  int64_t type;
+  int64_t length;
+} nghttp3_raw_frame_hd;
+
 /*
  * nghttp3_write_frame writes |fr| to |dest|.  This function
  * calculates the payload length and assigns it to fr->hd.length;
  */
-void nghttp3_write_frame(nghttp3_buf *dest, nghttp3_frame *fr);
+void nghttp3_write_frame(nghttp3_buf *dest, const nghttp3_frame *fr);
 
 /*
  * nghttp3_write_frame_qpack writes |fr| to |dest|.  |fr| is supposed
@@ -59,7 +69,7 @@ void nghttp3_write_frame(nghttp3_buf *dest, nghttp3_frame *fr);
  * calculates the payload length and assigns it to fr->hd.length;
  */
 void nghttp3_write_frame_qpack(nghttp3_buf *dest, nghttp3_qpack_encoder *qenc,
-                               int64_t stream_id, nghttp3_frame *fr);
+                               int64_t stream_id, const nghttp3_frame *fr);
 
 /*
  * nghttp3_write_frame_qpack_dyn is similar to
@@ -68,7 +78,7 @@ void nghttp3_write_frame_qpack(nghttp3_buf *dest, nghttp3_qpack_encoder *qenc,
  */
 void nghttp3_write_frame_qpack_dyn(nghttp3_buf *dest, nghttp3_buf *ebuf,
                                    nghttp3_qpack_encoder *qenc,
-                                   int64_t stream_id, nghttp3_frame *fr);
+                                   int64_t stream_id, const nghttp3_frame *fr);
 
 /*
  * nghttp3_write_frame_data writes DATA frame which has |len| bytes of
@@ -77,12 +87,13 @@ void nghttp3_write_frame_qpack_dyn(nghttp3_buf *dest, nghttp3_buf *ebuf,
 void nghttp3_write_frame_data(nghttp3_buf *dest, size_t len);
 
 /*
- * nghttp3_decode_frame_hd decodes frame header out of |vec| of length
- * |veccnt|.  It returns the number of bytes read if it succeeds, or
- * negative error code.
+ * nghttp3_decode_raw_frame_hd decodes frame header out of |vec| of
+ * length |veccnt|.  It returns the number of bytes read if it
+ * succeeds, or negative error code.
  */
-nghttp3_ssize nghttp3_decode_frame_hd(nghttp3_frame_hd *hd,
-                                      const nghttp3_vec *vec, size_t veccnt);
+nghttp3_ssize nghttp3_decode_raw_frame_hd(nghttp3_raw_frame_hd *hd,
+                                          const nghttp3_vec *vec,
+                                          size_t veccnt);
 
 /*
  * nghttp3_decode_priority_update_frame decodes PRIORITY_UPDATE frame
@@ -105,4 +116,13 @@ nghttp3_ssize nghttp3_decode_settings_frame(nghttp3_frame_settings *fr,
                                             const nghttp3_vec *vec,
                                             size_t veccnt);
 
+/*
+ * nghttp3_decode_origin_frame decodes ORIGIN frame out of |vec| of
+ * length |veccnt|.  It returns the number of bytes read if it
+ * succeeds, or a negative error code.
+ */
+nghttp3_ssize nghttp3_decode_origin_frame(nghttp3_frame_origin *fr,
+                                          const nghttp3_vec *vec,
+                                          size_t veccnt);
+
 #endif /* !defined(NGHTTP3_TEST_HELPER) */
